Index: third_party/WebKit/Source/core/layout/ng/ng_units.h |
diff --git a/third_party/WebKit/Source/core/layout/ng/ng_units.h b/third_party/WebKit/Source/core/layout/ng/ng_units.h |
index 43448ee7c8edb04737f60a27393091fadb1a9eb9..3e0e814118c60b637fe9ce7174517a6f52d36242 100644 |
--- a/third_party/WebKit/Source/core/layout/ng/ng_units.h |
+++ b/third_party/WebKit/Source/core/layout/ng/ng_units.h |
@@ -50,12 +50,12 @@ struct NGLogicalOffset { |
// Converts a logical offset to a physical offset. See: |
// https://drafts.csswg.org/css-writing-modes-3/#logical-to-physical |
// @param container_size the size of the rect (typically a fragment). |
// @param inner_size the size of the inner rect (typically a child fragment). |
CORE_EXPORT NGPhysicalOffset |
ConvertToPhysical(NGWritingMode mode, |
NGDirection direction, |
- NGPhysicalSize container_size, |
+ NGPhysicalSize outer_size, |
NGPhysicalSize inner_size) const; |
bool operator==(const NGLogicalOffset& other) const; |
@@ -50,12 +50,12 @@ struct NGLogicalOffset { |
// Converts a logical offset to a physical offset. See: |
// https://drafts.csswg.org/css-writing-modes-3/#logical-to-physical |
- // @param container_size the size of the rect (typically a fragment). |
+ // @param outer_size the size of the rect (typically a fragment). |
// @param inner_size the size of the inner rect (typically a child fragment). |
CORE_EXPORT NGPhysicalOffset |